import React, { useState, useRef, useEffect } from "react";
import { styled } from "@mui/material/styles";
import { useNavigate } from "react-router-dom";
import { Button, Typography, Grid, Tooltip } from "@mui/material";
import { useUndeployInDb } from "../../../api/SwaggerApi";
import { SimpleAccordion } from "../../common/Accordion/SimpleAccordion";
import { ConfirmationDialog } from "../../dialog/ConfirmationDialog";
import { SimpleModal } from "../../common/SimpleModal/SimpleModal";
import Alert from "@mui/material/Alert";
import AccessControl from "../../auth/AccessControl";
import { IocActiveDeployment } from "../../../api/DataTypes";

const PREFIX = "AdministerUndeployment";

const classes = {
  undeployButton: `${PREFIX}-undeployButton`
};

// TODO jss-to-styled codemod: The Fragment root was replaced by div. Change the tag if needed.
const Root = styled("div")({
  [`& .${classes.undeployButton}`]: {
    backgroundColor: "#aa2e25",
    color: "#FFFFFF",
    "&:disabled": {
      backgroundColor: "#e0e0e0",
      color: "#afaba6"
    },
    "&:hover": {
      backgroundColor: "#6c0000",
      color: "#FFFFFF"
    }
  }
});

export default function AdministerUndeployment({ ioc, buttonDisabled }) {
  const navigate = useNavigate();

  function onError(message) {
    setError(message);
  }

  // for the dialog
  const [error, setError] = useState();
  const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
  const [adHocDialogTitle, setAdHocDiatlogTitle] = useState();
  const [adHocDialogDescription, setAdHocDialogDescription] = useState();
  const callbackRef = useRef();

  const [response, undeployIOC] = useUndeployInDb(ioc.id, onError);

  // Setting up dialog properties
  const openUndeployModal = () => {
    setAdHocDiatlogTitle("Administratively 'undeploy' IOC");
    setAdHocDialogDescription(
      <Root>
        <Typography style={{ display: "inline-block" }}>
          Are you sure want to administer IOC as undeployed &nbsp;
        </Typography>
        <Typography
          style={{ fontFamily: "monospace", display: "inline-block" }}
        >
          {" "}
          {ioc.namingName}?{" "}
        </Typography>
      </Root>
    );
    callbackRef.current = undeployIoc;
    setAdHocDialogOpen(true);
  };

  // what to do when "undeploying" the IOC
  const undeployIoc = async () => {
    undeployIOC();
  };

  useEffect(() => {
    if (response) {
      navigate(-1);
    }
  }, [response, navigate]);

  const failedDeployment = new IocActiveDeployment(
    ioc.activeDeployment
  ).failedDeployment();

  let disabledButtonTitle = "";
  if (buttonDisabled || ioc.operationInProgress) {
    disabledButtonTitle =
      "There is an ongoing operation, you cannot 'undeploy' the IOC right now";
  } else {
    if (!failedDeployment) {
      disabledButtonTitle =
        "IOC doesn't have failed (un)deployment, you cannot 'undeploy' it";
    }
  }

  return (
    <Root>
      <AccessControl
        allowedRoles={["DeploymentToolAdmin"]}
        renderNoAccess={() => <></>}
      >
        <>
          <SimpleModal
            open={adHocDialogOpen}
            setOpen={setAdHocDialogOpen}
          >
            <ConfirmationDialog
              open={adHocDialogOpen}
              setOpen={setAdHocDialogOpen}
              title={adHocDialogTitle}
              description={adHocDialogDescription}
              callback={callbackRef.current}
            />
          </SimpleModal>

          <SimpleAccordion
            summary="Change deployment status to not deployed (e.g. if IOC has been manually removed)"
            defaultExpanded
          >
            <Grid
              container
              spacing={1}
            >
              {error ? (
                <Grid
                  item
                  xs={12}
                >
                  <Alert severity="error">{error}</Alert>
                </Grid>
              ) : (
                <></>
              )}
              <Grid
                item
                xs={12}
              >
                <Tooltip title={disabledButtonTitle}>
                  <span>
                    <Button
                      className={classes.undeployButton}
                      onClick={openUndeployModal}
                      disabled={
                        buttonDisabled ||
                        ioc.operationInProgress ||
                        !failedDeployment
                      }
                    >
                      SET DEPLOYMENT STATE TO NOT DEPLOYED
                    </Button>
                  </span>
                </Tooltip>
              </Grid>
            </Grid>
          </SimpleAccordion>
        </>
      </AccessControl>
    </Root>
  );
}
