import React, { useState, useRef, useEffect } from "react";
import { styled } from "@mui/material/styles";
import { useNavigate } from "react-router-dom";
import { Button, Typography, Grid, Tooltip } from "@mui/material";
import { useDeleteIOC } from "../../../api/SwaggerApi";
import { SimpleAccordion } from "../../common/Accordion/SimpleAccordion";
import { ConfirmationDialog } from "../../dialog/ConfirmationDialog";
import { SimpleModal } from "../../common/SimpleModal/SimpleModal";
import Alert from "@mui/material/Alert";
import AccessControl from "../../auth/AccessControl";

const PREFIX = "IOCDelete";

const classes = {
  deleteButton: `${PREFIX}-deleteButton`
};

// TODO jss-to-styled codemod: The Fragment root was replaced by div. Change the tag if needed.
const Root = styled("div")({
  [`& .${classes.deleteButton}`]: {
    backgroundColor: "#aa2e25",
    color: "#FFFFFF",
    "&:disabled": {
      backgroundColor: "#e0e0e0",
      color: "#afaba6"
    },
    "&:hover": {
      backgroundColor: "#6c0000",
      color: "#FFFFFF"
    }
  }
});

export default function IOCDelete({ ioc, buttonDisabled }) {
  const navigate = useNavigate();

  function onError(message) {
    setError(message);
  }

  // for the dialog
  const [error, setError] = useState();
  const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
  const [adHocDialogTitle, setAdHocDiatlogTitle] = useState();
  const [adHocDialogDescription, setAdHocDialogDescription] = useState();
  const callbackRef = useRef();

  const [response, deleteIOC] = useDeleteIOC(ioc.id, onError);

  // Setting up dialog properties
  const openDeleteModal = () => {
    setAdHocDiatlogTitle("Deleting IOC");
    setAdHocDialogDescription(
      <Root>
        <Typography style={{ display: "inline-block" }}>
          Are you sure want to delete &nbsp;
        </Typography>
        <Typography
          style={{ fontFamily: "monospace", display: "inline-block" }}
        >
          {" "}
          {ioc.namingName}?{" "}
        </Typography>
      </Root>
    );
    callbackRef.current = deleteIoc;
    setAdHocDialogOpen(true);
  };

  // what to do when deleting IOC
  const deleteIoc = async () => {
    deleteIOC();
  };

  useEffect(() => {
    if (response && !error) {
      navigate(-1);
    }
  }, [response, navigate, error]);

  let disabledButtonTitle = "";

  if (buttonDisabled || ioc.operationInProgress) {
    disabledButtonTitle =
      "There is an ongoing operation, you can not delete the IOC right now";
  }

  return (
    <Root>
      <SimpleModal
        open={adHocDialogOpen}
        setOpen={setAdHocDialogOpen}
      >
        <ConfirmationDialog
          open={adHocDialogOpen}
          setOpen={setAdHocDialogOpen}
          title={adHocDialogTitle}
          description={adHocDialogDescription}
          callback={callbackRef.current}
        />
      </SimpleModal>

      <SimpleAccordion
        summary="Delete IOC"
        defaultExpanded
      >
        <Grid
          container
          spacing={1}
        >
          {error ? (
            <Grid
              item
              xs={12}
            >
              <Alert severity="error">{error}</Alert>
            </Grid>
          ) : (
            <></>
          )}
          <Grid
            item
            xs={12}
          >
            <AccessControl
              allowedRoles={["DeploymentToolAdmin"]}
              renderNoAccess={() => (
                <Tooltip title={"Only admins can delete the IOC"}>
                  <span>
                    <Button
                      className={classes.deleteButton}
                      disabled
                    >
                      Delete IOC
                    </Button>
                  </span>
                </Tooltip>
              )}
            >
              <Tooltip title={disabledButtonTitle}>
                <span>
                  <Button
                    className={classes.deleteButton}
                    onClick={openDeleteModal}
                    disabled={
                      buttonDisabled ||
                      ioc.operationInProgress ||
                      ioc.activeDeployment
                    }
                  >
                    Delete IOC
                  </Button>
                </span>
              </Tooltip>
            </AccessControl>
          </Grid>
        </Grid>
      </SimpleAccordion>
    </Root>
  );
}
