import React, { useEffect } from "react";
import { useTagsAndCommitIds } from "../../api/SwaggerApi";
import { JobTable } from "./JobTable";

export function JobAsyncList({
  jobs,
  setJobs,
  rowType,
  pagination,
  onPage,
  loading
}) {
  const jobDetailFetchers = jobs?.map((job, index) => (
    <JobDetailFetcher
      key={`${job.type}-fetcher-${job.id}`}
      deployment={job}
      index={index}
      setDeployments={setJobs}
    />
  ));
  return (
    <>
      <JobTable
        jobs={jobs}
        rowType={rowType}
        pagination={pagination}
        onPage={onPage}
        loading={loading}
      />
      {jobDetailFetchers}
    </>
  );
}

function onError(message) {
  console.warn(message);
}

export function JobDetailFetcher({ deployment, index, setDeployments }) {
  const [tagOrCommitId, getTagOrCommitId] = useTagsAndCommitIds(onError);

  useEffect(() => {
    getTagOrCommitId(
      deployment.gitProjectId,
      deployment.gitReference,
      false,
      "EQUALS"
    );
  }, [deployment, getTagOrCommitId]);

  useEffect(() => {
    setDeployments((deployments) => {
      deployments[index].sourceVersionShort =
        tagOrCommitId?.length === 1
          ? tagOrCommitId[0].shortReference
          : deployments[index].gitReference;
      deployments[index].host.hostInfoFromCache = false;
      return [...deployments];
    });
  }, [index, setDeployments, tagOrCommitId]);

  return null;
}
