import React from "react";
import { styled } from "@mui/material/styles";
import { Paper, Typography, Box, Button } from "@mui/material";
import { RootContainer } from "../../common/Container/RootContainer";
import { useRedirect } from "../../../hooks/Redirect";

const PREFIX = "AccessDenied";

const classes = {
  paper: `${PREFIX}-paper`
};

const StyledRootContainer = styled(RootContainer)(({ theme }) => ({
  [`& .${classes.paper}`]: {
    maxWidth: "80%",
    padding: theme.spacing(4)
  }
}));

export default function AccessDenied() {
  const redirect = useRedirect();

  const goHome = () => {
    redirect("/iocs");
  };

  return (
    <StyledRootContainer>
      <Paper className={classes.paper}>
        <Box
          display="flex"
          justifyContent="center"
          p={2}
          m={1}
        >
          <Typography variant="h4">Access denied</Typography>
        </Box>
        <Box
          display="flex"
          justifyContent="center"
        >
          <Typography variant="body1">
            You do not have permission to access this page. Please contact an
            administrator to request access.
          </Typography>
        </Box>
        <Box
          display="flex"
          justifyContent="center"
          p={2}
          m={1}
        >
          <Button
            variant="contained"
            color="secondary"
            onClick={goHome}
          >
            Return to Home
          </Button>
        </Box>
      </Paper>
    </StyledRootContainer>
  );
}
