import React from "react";
import { styled } from "@mui/material/styles";
import { useSnackbar } from "notistack";
import { Button } from "@mui/material";
const PREFIX = "Snackbar";

const classes = {
  text: `${PREFIX}-text`
};

const StyledButton = styled(Button)(({ theme }) => ({
  [`&.${classes.text}`]: {
    color: "#f0f0f0",
    borderColor: "#f0f0f0",
    "&:hover": {
      backgroundColor: "#8d8d8d",
      borderColor: "#8d8d8d",
      boxShadow: "none"
    }
  }
}));

export function useCustomSnackbar() {
  const { enqueueSnackbar, closeSnackbar } = useSnackbar();

  function showError(errorMessage, severity = "error") {
    console.error("Snackbar: " + errorMessage);
    const action = (key) => (
      <StyledButton
        variant="text"
        className={classes.text}
        onClick={() => {
          closeSnackbar(key);
        }}
      >
        Dismiss
      </StyledButton>
    );
    enqueueSnackbar(errorMessage, {
      variant: severity,
      autoHideDuration: null,
      action
    });
  }

  return showError;
}
